@@ -97,6 +97,12 @@ mod tests {
         assert_eq!(value, JsonValue::String(String::from("test")));
     }
 
+    #[test]
+    fn it_should_parse_string_with_quotes() {
+        let value = parse_to_value(r#""echo \"test\"""#).unwrap().unwrap();
+        assert_eq!(value, JsonValue::String(String::from(r#"echo "test""#)));
+    }
+
     #[test]
     fn it_should_parse_array() {
         let value = parse_to_value(r#"[false, true]"#).unwrap().unwrap();
